You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ws.apache.org by ve...@apache.org on 2016/05/07 20:12:20 UTC

svn commit: r1742746 - in /webservices/woden/trunk/java/woden-converter-maven-plugin: ./ src/it/ src/it/basic/ src/it/basic/src/ src/it/basic/src/main/ src/it/basic/src/main/wsdl/ src/it/cli/ src/main/java/org/apache/woden/converter/maven2/

Author: veithen
Date: Sat May  7 20:12:20 2016
New Revision: 1742746

URL: http://svn.apache.org/viewvc?rev=1742746&view=rev
Log:
WODEN-241: Upgrade woden-converter-maven-plugin to use Java 5 annotations instead of old-style javadoc tags and implement the necessary changes to make it usable as CLI. Patch submitted by hboutemy.

Added:
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml   (with props)
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml   (with props)
Modified:
    webservices/woden/trunk/java/woden-converter-maven-plugin/pom.xml
    webservices/woden/trunk/java/woden-converter-maven-plugin/src/main/java/org/apache/woden/converter/maven2/ConverterMojo.java

Modified: webservices/woden/trunk/java/woden-converter-maven-plugin/pom.xml
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/pom.xml?rev=1742746&r1=1742745&r2=1742746&view=diff
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/pom.xml (original)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/pom.xml Sat May  7 20:12:20 2016
@@ -45,10 +45,46 @@
         <plugins>
             <plugin>
                 <artifactId>maven-plugin-plugin</artifactId>
-                <version>2.5</version>
                 <configuration>
                     <goalPrefix>woden</goalPrefix>
                 </configuration>
+                <executions>
+                    <execution>
+                        <id>default-descriptor</id>
+                        <phase>process-classes</phase>
+                    </execution>
+                    <execution>
+                        <id>generate-helpmojo</id>
+                        <goals>
+                            <goal>helpmojo</goal>
+                        </goals>
+                    </execution>
+                </executions>
+            </plugin>
+            <plugin>
+                <artifactId>maven-invoker-plugin</artifactId>
+                <configuration>
+                    <debug>true</debug>
+                    <projectsDirectory>src/it</projectsDirectory>
+                    <cloneProjectsTo>${project.build.directory}/it</cloneProjectsTo>
+                    <preBuildHookScript>setup</preBuildHookScript>
+                    <postBuildHookScript>verify</postBuildHookScript>
+                    <localRepositoryPath>${project.build.directory}/local-repo</localRepositoryPath>
+                    <settingsFile>src/it/settings.xml</settingsFile>
+                    <pomIncludes>
+                        <pomInclude>*/pom.xml</pomInclude>
+                    </pomIncludes>
+                </configuration>
+                <executions>
+                    <execution>
+                        <id>integration-test</id>
+                        <goals>
+                            <goal>install</goal>
+                            <goal>integration-test</goal>
+                            <goal>verify</goal>
+                        </goals>
+                    </execution>
+                </executions>
             </plugin>
             <plugin>
                 <groupId>org.codehaus.plexus</groupId>
@@ -83,5 +119,11 @@
             <artifactId>maven-plugin-api</artifactId>
             <version>2.0.3</version>
         </dependency>
+        <dependency>
+            <groupId>org.apache.maven.plugin-tools</groupId>
+            <artifactId>maven-plugin-annotations</artifactId>
+            <version>3.4</version>
+            <scope>provided</scope>
+        </dependency>
     </dependencies>
 </project>

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties Sat May  7 20:12:20 2016
@@ -0,0 +1,18 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
+invoker.goals = generate-sources

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/invoker.properties
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml Sat May  7 20:12:20 2016
@@ -0,0 +1,56 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
+  <modelVersion>4.0.0</modelVersion>
+
+  <groupId>org.apache.woden.its</groupId>
+  <artifactId>basic</artifactId>
+  <version>1.0</version>
+
+  <name>Basic Woden converter test</name>
+  <description>
+    Basic test.
+  </description>
+
+  <build>
+    <plugins>
+      <plugin>
+        <groupId>org.apache.woden</groupId>
+        <artifactId>woden-converter-maven-plugin</artifactId>
+        <version>@project.version@</version>
+        <configuration>
+            <wsdl>src/main/wsdl/HelloService.wsdl</wsdl>
+            <verbose>true</verbose>
+            <overwrite>true</overwrite>
+        </configuration>
+        <executions>
+            <execution>
+                <goals>
+                    <goal>convert</goal>
+                </goals>
+            </execution>
+        </executions>
+      </plugin>
+    </plugins>
+  </build>
+
+</project>

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/pom.xml
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl Sat May  7 20:12:20 2016
@@ -0,0 +1,61 @@
+<?xml version="1.0" encoding="utf-8" ?>
+<!-- ! ! Licensed to the Apache Software Foundation (ASF) under one or more 
+	! contributor license agreements. See the NOTICE file distributed with ! 
+	this work for additional information regarding copyright ownership. ! The 
+	ASF licenses this file to You under the Apache License, Version 2.0 ! (the 
+	"License"); you may not use this file except in compliance with ! the License. 
+	You may obtain a copy of the License at ! ! http://www.apache.org/licenses/LICENSE-2.0 
+	! ! Unless required by applicable law or agreed to in writing, software ! 
+	distributed under the License is distributed on an "AS IS" BASIS, ! WITHOUT 
+	WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. ! See the 
+	License for the specific language governing permissions and ! limitations 
+	under the License. ! -->
+<definitions name="HelloService"
+   targetNamespace="http://www.ecerami.com/wsdl/HelloService.wsdl"
+   xmlns="http://schemas.xmlsoap.org/wsdl/"
+   xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
+   xmlns:tns="http://www.ecerami.com/wsdl/HelloService.wsdl"
+   xmlns:xsd="http://www.w3.org/2001/XMLSchema">
+ 
+   <message name="SayHelloRequest">
+      <part name="firstName" type="xsd:string"/>
+   </message>
+   <message name="SayHelloResponse">
+      <part name="greeting" type="xsd:string"/>
+   </message>
+ 
+   <portType name="Hello_PortType">
+      <operation name="sayHello">
+         <input message="tns:SayHelloRequest"/>
+         <output message="tns:SayHelloResponse"/>
+      </operation>
+   </portType>
+   
+   <binding name="Hello_Binding" type="tns:Hello_PortType">
+      <soap:binding style="rpc" 
+         transport="http://schemas.xmlsoap.org/soap/http"/>
+      <operation name="sayHello">
+         <soap:operation soapAction="sayHello"/>
+         <input>
+            <soap:body
+               encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
+               namespace="urn:examples:helloservice"
+               use="encoded"/>
+         </input>
+         <output>
+            <soap:body
+               encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
+               namespace="urn:examples:helloservice"
+               use="encoded"/>
+         </output>
+      </operation>
+   </binding>
+ 
+   <service name="Hello_Service">
+      <documentation>WSDL File for HelloService</documentation>
+      <port binding="tns:Hello_Binding" name="Hello_Port">
+         <soap:address 
+            location="http://localhost:8080/soap/servlet/rpcrouter"/>
+      </port>
+   </service>
+</definitions>
\ No newline at end of file

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/basic/src/main/wsdl/HelloService.wsdl
------------------------------------------------------------------------------
--- svn:mime-type (added)
+++ svn:mime-type Sat May  7 20:12:20 2016
@@ -0,0 +1 @@
+text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl Sat May  7 20:12:20 2016
@@ -0,0 +1,61 @@
+<?xml version="1.0" encoding="utf-8" ?>
+<!-- ! ! Licensed to the Apache Software Foundation (ASF) under one or more 
+	! contributor license agreements. See the NOTICE file distributed with ! 
+	this work for additional information regarding copyright ownership. ! The 
+	ASF licenses this file to You under the Apache License, Version 2.0 ! (the 
+	"License"); you may not use this file except in compliance with ! the License. 
+	You may obtain a copy of the License at ! ! http://www.apache.org/licenses/LICENSE-2.0 
+	! ! Unless required by applicable law or agreed to in writing, software ! 
+	distributed under the License is distributed on an "AS IS" BASIS, ! WITHOUT 
+	WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. ! See the 
+	License for the specific language governing permissions and ! limitations 
+	under the License. ! -->
+<definitions name="HelloService"
+   targetNamespace="http://www.ecerami.com/wsdl/HelloService.wsdl"
+   xmlns="http://schemas.xmlsoap.org/wsdl/"
+   xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
+   xmlns:tns="http://www.ecerami.com/wsdl/HelloService.wsdl"
+   xmlns:xsd="http://www.w3.org/2001/XMLSchema">
+ 
+   <message name="SayHelloRequest">
+      <part name="firstName" type="xsd:string"/>
+   </message>
+   <message name="SayHelloResponse">
+      <part name="greeting" type="xsd:string"/>
+   </message>
+ 
+   <portType name="Hello_PortType">
+      <operation name="sayHello">
+         <input message="tns:SayHelloRequest"/>
+         <output message="tns:SayHelloResponse"/>
+      </operation>
+   </portType>
+   
+   <binding name="Hello_Binding" type="tns:Hello_PortType">
+      <soap:binding style="rpc" 
+         transport="http://schemas.xmlsoap.org/soap/http"/>
+      <operation name="sayHello">
+         <soap:operation soapAction="sayHello"/>
+         <input>
+            <soap:body
+               encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
+               namespace="urn:examples:helloservice"
+               use="encoded"/>
+         </input>
+         <output>
+            <soap:body
+               encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
+               namespace="urn:examples:helloservice"
+               use="encoded"/>
+         </output>
+      </operation>
+   </binding>
+ 
+   <service name="Hello_Service">
+      <documentation>WSDL File for HelloService</documentation>
+      <port binding="tns:Hello_Binding" name="Hello_Port">
+         <soap:address 
+            location="http://localhost:8080/soap/servlet/rpcrouter"/>
+      </port>
+   </service>
+</definitions>
\ No newline at end of file

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/HelloService.wsdl
------------------------------------------------------------------------------
--- svn:mime-type (added)
+++ svn:mime-type Sat May  7 20:12:20 2016
@@ -0,0 +1 @@
+text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties Sat May  7 20:12:20 2016
@@ -0,0 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
+#invoker.goals = -Dwoden.converter.wsdl=HelloService.wsdl woden:convert
+invoker.goals = -Dwoden.converter.wsdl=HelloService.wsdl -Dwoden.converter.overwrite org.apache.woden:woden-converter-maven-plugin:${project.version}:convert

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/invoker.properties
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml Sat May  7 20:12:20 2016
@@ -0,0 +1,33 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
+  <modelVersion>4.0.0</modelVersion>
+
+  <groupId>org.apache.woden.its</groupId>
+  <artifactId>cli</artifactId>
+  <version>1.0</version>
+
+  <name>Basic Woden converter CLI test</name>
+  <description>
+    Notice: this requires to configure org.apache.woden as pluginGroup in settings.xml
+  </description>
+</project>

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/cli/pom.xml
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml?rev=1742746&view=auto
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml (added)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml Sat May  7 20:12:20 2016
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+
+<settings xmlns="http://maven.apache.org/SETTINGS/1.1.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+  xsi:schemaLocation="http://maven.apache.org/SETTINGS/1.1.0 http://maven.apache.org/xsd/settings-1.1.0.xsd">
+  <pluginGroups>
+    <pluginGroup>org.apache.woden</pluginGroup>
+  </pluginGroups>
+  <profiles>
+    <profile>
+      <id>it-repo</id>
+      <activation>
+        <activeByDefault>true</activeByDefault>
+      </activation>
+      <repositories>
+        <repository>
+          <id>local.central</id>
+          <url>@localRepositoryUrl@</url>
+          <releases>
+            <enabled>true</enabled>
+          </releases>
+          <snapshots>
+            <enabled>true</enabled>
+          </snapshots>
+        </repository>
+      </repositories>
+      <pluginRepositories>
+        <pluginRepository>
+          <id>local.central</id>
+          <url>@localRepositoryUrl@</url>
+          <releases>
+            <enabled>true</enabled>
+          </releases>
+          <snapshots>
+            <enabled>true</enabled>
+          </snapshots>
+        </pluginRepository>
+      </pluginRepositories>
+    </profile>
+  </profiles>
+</settings>

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: webservices/woden/trunk/java/woden-converter-maven-plugin/src/it/settings.xml
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: webservices/woden/trunk/java/woden-converter-maven-plugin/src/main/java/org/apache/woden/converter/maven2/ConverterMojo.java
URL: http://svn.apache.org/viewvc/webservices/woden/trunk/java/woden-converter-maven-plugin/src/main/java/org/apache/woden/converter/maven2/ConverterMojo.java?rev=1742746&r1=1742745&r2=1742746&view=diff
==============================================================================
--- webservices/woden/trunk/java/woden-converter-maven-plugin/src/main/java/org/apache/woden/converter/maven2/ConverterMojo.java (original)
+++ webservices/woden/trunk/java/woden-converter-maven-plugin/src/main/java/org/apache/woden/converter/maven2/ConverterMojo.java Sat May  7 20:12:20 2016
@@ -24,69 +24,63 @@ import org.apache.maven.plugin.AbstractM
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
 import org.apache.maven.plugin.logging.Log;
+import org.apache.maven.plugins.annotations.LifecyclePhase;
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.Parameter;
+import org.apache.maven.plugins.annotations.ResolutionScope;
 import org.apache.woden.tool.converter.Convert;
 
 /**
  * <p>
  * This is used to invoke Woden WSDL converter as Maven2 plug-in.
  * Following meta data required  for this Mojo.
  * </p>
  * <p>
  * It is possible run this command using
  * "mvn woden:convert" command.
  * </p>
  * 
- * @goal convert
- * @execute phase="generate-sources"
- * @requiresDependencyResolution runtime  *
- * @description Woden Converter Maven plig-in
  * @author Sagara Gunathunga
  */
+@Mojo(name = "convert", defaultPhase = LifecyclePhase.GENERATE_SOURCES, requiresDependencyResolution = ResolutionScope.RUNTIME)
 public class ConverterMojo extends AbstractMojo {
 
     /** 
-     * File or URL of wsdl1.1 document.Also multiple
+     * File or URL of wsdl1.1 document. Also multiple
      * WSDL files can be specified as a comma separated list.
-     * 
-     * @parameter expression="${woden.converter.wsdl}"
-     * @required
      */
+    @Parameter(property = "woden.converter.wsdl", required = true)
     private String wsdl;
 
     /** 
      * New target namespace for WSDL2.0 document.
-     * 
-     * @parameter expression="${woden.converter.wsdl}" 
      */
+    @Parameter
     private String targetNS;
 
     /** 
-     * Target directory for out put, default 
+     * Target directory for output, default 
      * location is project build directory. 
-     * 
-     * @parameter expression="${woden.converter.wsdl}" default-value="${project.build.directory}"
      */
+    @Parameter(defaultValue = "${project.build.directory}")
     private String targetDir;
 
     /** 
-     * sourceDir directory for out put. 
-     * 
-     * @parameter expression="${woden.converter.wsdl}" 
+     * sourceDir directory for output. 
      */
+    @Parameter
     private String sourceDir;
 
     /** 
      * verbose option. 
-     * 
-     * @parameter expression="${woden.converter.wsdl}"
      */
+    @Parameter(property = "woden.converter.verbose")
     private boolean verbose;
 
     /** 
-     * Overwrite existing files. 
-     * 
-     * @parameter expression="${woden.converter.wsdl}"
+     * Overwrite existing files.
      */
+    @Parameter(property = "woden.converter.overwrite")
     private boolean overwrite;
     
 
@@ -109,7 +103,7 @@ public class ConverterMojo extends Abstr
     }
 
     /**
-     * Convert each WSDL1.1 file in to WSDL2.0 file.     * 
+     * Convert each WSDL1.1 file in to WSDL2.0 file.
      */
     private void convertEachFile(String wsdlFile) throws MojoFailureException,
             MojoExecutionException {
@@ -24,69 +24,63 @@ import org.apache.maven.plugin.AbstractM
 /**
  * <p>
- * This is used to invoke Woden WSDL converter as Maven2 plug-in.
- * Following meta data required  for this Mojo.
+ * Woden Converter Maven: it is used to invoke Woden WSDL converter as Maven plugin.
+ * Following meta data required for this Mojo.
  * </p>
  * <p>